@@ -2,10 +2,9 @@ gallery <- gallery_rd3
 
 asGallery <- function(net){
   if(inherits(net,"network_rd3")){
-    nodes <- net$nodes
     options <- net$options
-    gallery <- gallery_rd3(nodes = nodes, name = options$nodeName, label = options$nodeLabel,
-      color = options$nodeColor, ntext = options$nodeText, info = options$nodeInfo, image = options$imageItems,
+    gallery <- gallery_rd3(nodes = net$nodes, tree = net$tree, name = options$nodeName, label = options$nodeLabel,
+      color = options$nodeColor, border = options$nodeBorder, ntext = options$nodeText, info = options$nodeInfo, image = options$imageItems,
       zoom = options$zoom, main = options$main, note = options$note,
       showLegend = options$showLegend, frequencies = options$frequencies,
       help = options$help, helpOn = options$helpOn, cex = options$cex, language = options$language)
